API docs for “spamfighter.core.counters”

# Module s.c.counters

Part of spamfighter.core View Source

Счетчики, анализирующие нагрузку на сервер.

Class | ICounter | Счетчик, аккумулирующий информацию по группе одиночных счетчиков `IAtomCounter`.
Class | IAtomCounter | Одиночный счетчик (одно значение). Счетчик рассчитывает своё
Class | AtomCounterPeriod | Одиночный счетчик, рассчитывающий своё значение за конечный
Class | AtomCounterEternal | Одиночный счетчик за "весь период" (с момента создания счетчика).
Class | Counter | Набор одиночных счетчиков, вместе рассчитывающих одно значение
Class | SpeedCounter | Счетчик, измеряющий "скорость" величины (отношение ко времени).
Class | AverageCounter | Счетчик, измеряющий среднее значение величины.
Class | RequestCounter | Счетчик числа запросов.
Class | RequestPerSecondCounter | Счетчик числа запросов в секунду.
Class | AverageServiceTimeCounter | Счетчик среднего времени обслуживания.